#include <vector>
#include <iostream>
#include <unordered_set>
#include <stack>
#include <algorithm>
#include <unordered_map>
#include <exception>
#include <numeric>
#include <utility>

#define TASK2
// #define DEBUG

#ifdef DEBUG
#define BR std::cout << "\n\n";
#endif // DEBUG

#ifdef TASK1

int main(int, char **)
{
    int k;
    int n;
    std::vector<long int> ram;
    std::cin >> n >> k;
    ram.reserve(n);
    for (auto i = 0, curr = 0; i < n; ++i)
    {
        std::cin >> curr;
        ram.push_back(curr);
    }

    return 0;
}

#elif defined TASK3

struct node
{
    int num;
    int color;
    std::vector<int> links;
};

using _Treetype = std::vector<node>;
template <typename T>
using _Stack_of_refs = std::stack<std::reference_wrapper<T>>;

// Globals
_Treetype tree;

struct dfs_stats
{
    int found_paths{0};
    int found_x{0};
    int found_y{0};
    int target_x{-1};
    int target_y{-1};
    std::vector<node> path;
    std::vector<std::vector<int>> visited;

    dfs_stats(int x, int y) : target_x{x}, target_y{y} {}

    bool check_condition()
    {
        auto old = found_paths;
        if (found_x == 2 && found_y >= 1) {
            ++found_paths;
            #ifdef DEBUG
            std::cout << "Found enough - " << found_x << " X(" << target_x << ") and " << found_y << " Y(" << target_y << ")\n";
            std::cout << "Path: ";
            for (const auto &l: path)
                std::cout << l.num << ' ';
            std::cout << '\n';
            #endif
        }
        return old != found_paths;
    }

    bool check_visited() {
        std::vector<int> checked;
        for (const auto &n: path)
            if (n.color == target_x || n.color == target_y)
                checked.push_back(n.num);
        std::sort(checked.begin(), checked.end());

        for (const auto &visited_path: visited) {
            if (visited_path.size() > checked.size() && std::includes(visited_path.cbegin(), visited_path.cend(), checked.cbegin(), checked.cend()))
                return true;
            if (std::includes(checked.cbegin(), checked.cend(), visited_path.cbegin(), visited_path.cend()))
                return true;
        }

        visited.push_back(std::move(checked));
        return false;
    }
};

#ifdef DEBUG
void print_path(const std::vector<node> &st) {
    std::cout << "Path so far: ";
    for (const auto &node: st) {
        std::cout << node.num << ' ';
    }
    std::cout << '\n';
}
#endif

void dfs(const node &curr_node, dfs_stats &sdfs)
{
    sdfs.found_x += (curr_node.color == sdfs.target_x);
    sdfs.found_y += (curr_node.color == sdfs.target_y);
    #ifdef DEBUG
    std::cout << "In node #" << curr_node.num << '\n';
    print_path(sdfs.path);
    #endif

    if (sdfs.check_condition() && !sdfs.check_visited()) {
        goto ret;
    }
    if (curr_node.links.empty())
        goto ret;

    sdfs.path.push_back(curr_node);
    for (auto&& link: curr_node.links){
        #ifdef DEBUG
        std::cout << "Accessing link @" << link << '\n';
        #endif
        if (std::find_if(sdfs.path.cbegin(), sdfs.path.cend(), [&](const node &n) { return n.num == link; }) == sdfs.path.cend())
            dfs(tree.at(link), sdfs);
    }
    sdfs.path.pop_back();

ret:
#ifdef DEBUG
    std::cout << "Returning from node #" << curr_node.num << '\n';
#endif
    return;
}

std::vector<std::vector<std::vector<int>>> all;
int query(int x, int y, const std::unordered_set<int> &root_candidates)
{
    int total_found_paths = 0;
    for (auto &&root_node_num: root_candidates) {
        dfs_stats sdfs{x, y};
        #ifdef DEBUG
        std::cout << "Querying for colors X = " << x << " and Y = " << y << "; Starting from node #" << root_node_num << '\n';
        #endif
        dfs(tree.at(root_node_num), sdfs);
        total_found_paths += sdfs.found_paths;

        all.push_back(std::move(sdfs.visited));
    }
    return total_found_paths;
}

#ifdef DEBUG
void print_node(const node &_node) {
    std::cout << "Node {\n\tnum = " << _node.num << ",\n\tcolor = " << _node.color << ",\n\tlinks = [";
    for (auto &&l: _node.links)
        std::cout << l << ' ';
    std::cout << "]\n};\n";
}
#endif

int main(int, char **)
{
    int num_nodes;
    std::unordered_set<int> colors;

    std::cin >> num_nodes;
    tree.reserve(num_nodes + 1);

    tree.emplace_back(); // dummy
    tree.back().num = -1;
    tree.back().color = -1;
    tree.back().links.emplace_back(-1);

    for (auto i = 1; i <= num_nodes; ++i)
    {
        node nn;
        std::cin >> nn.color;
        colors.emplace(nn.color);
        nn.num = i;
        tree.push_back(nn);
    }

    std::unordered_set<int> root_condidates;
    root_condidates.reserve(num_nodes);
    for (int i = 1; i <= num_nodes; ++i)
        root_condidates.emplace(i);

    enum LinkAssignment {
        In,
        Out,
        None
    };
    std::cout << "Reached link =\n";

    std::unordered_map<int, LinkAssignment> node_links_assignments;
    for (auto i = 0, k = 0, v = 0; i < num_nodes - 1; ++i)
    {
        std::cin >> k >> v;
        std::cout << "Add " << v << " as a link to " << k << '\n';
        tree[k].links.push_back(v);
        tree[v].links.push_back(k);

        try {
        if (node_links_assignments.at(k) == In)
            root_condidates.erase(k);
        if (node_links_assignments.at(v) == Out)
            root_condidates.erase(v);
        } catch (std::exception &e) {}
        node_links_assignments[k] = Out;
        node_links_assignments[v] = In;
    }
    std::cout << "Reached 178\n";
#ifdef DEBUG
    {
        for (const node &_node : tree)
            print_node(_node);

        BR

        std::cout << "Root candidates: ";
        for (auto &&rc: root_condidates)
        {
            std::cout << rc << ' ';
        }

        BR

        std::cout << "Colors: ";
        for (auto&& col: colors)
        {
            std::cout << col << ' ';
        }

        BR
    }
#endif
    int num_queries;
    std::cin >> num_queries;
    int x;
    int y;

    std::cout << "Reached 208\n";

    std::vector<int> results;
    results.reserve(num_queries);
    for (int i = 0, num_paths = 0; i < num_queries; ++i)
    {
        std::cin >> x;
        std::cin >> y;

        if (colors.find(x) == colors.cend() || colors.find(y) == colors.cend())
            num_paths = 0;
        else
            num_paths = query(x, y, root_condidates);
        results.emplace_back(num_paths);
    }

    for (auto &&res: results)
    {
        std::cout << res << '\n';
    }

    return 0;
}

#elif defined TASK2

#define MegabyteMinutes(mb, m) (mb) * (m)

// #define DEBUG

int main(int, char **) {
    int num_simu;
    int num_tasks;

    std::cin >> num_simu >> num_tasks;

    std::vector<int> space;
    space.reserve(num_simu);
    for (int i = 0; i < num_simu; ++i)
    {
        int curr;
        std::cin >> curr;
        space.push_back(curr);
    }

    std::sort(space.begin(), space.end());

    std::vector<int> bounds;
    bounds.reserve(num_tasks);

    int default_bound_gap = num_simu / num_tasks;

    using window = std::pair<int, int>;
    std::vector<window> windows;
    windows.reserve(num_tasks);
    windows.emplace_back(0, default_bound_gap);
    for (int i = 1; i < num_tasks; ++i)
        windows.emplace_back(windows.back().second + 1, windows.back().second + default_bound_gap);
    windows.back().second = num_simu;

    #ifdef DEBUG
    for (int i = 0; i < num_tasks; ++i)  {
        std::cout << "Window #" << i << ": [" << windows.at(i).first << ", " << windows.at(i).second << ")\n";
    }
    #endif

    auto window_weight = [&](const auto &window) {
        return *std::max_element(space.cbegin() + window.first, space.cbegin() + window.second);
    };

    auto windows_weight = [&](const auto &windows) {
        return std::accumulate(windows.cbegin(), windows.cend(), 0, [&](auto &&init, const auto &elem) {
            return init + window_weight(elem) * (elem.second - elem.first + 1);
        });
    };

#ifdef DEBUG
    std::cout << "Space (sorted): ";
    for (auto &&s: space)
        std::cout << s << ' ';
    std::cout << '\n';

    for (const auto &window: windows) {
        const auto initial_weight = window_weight(window);
        std::cout << initial_weight << '\n';
    }
#endif

    auto inc_window = [&](auto &window, const auto window_idx) {
        if (window_idx < windows.size()) {
            window.second += 1;
            windows[window_idx + 1].first -= 1;
        }
    };

    // Shuffle windows a bit
    for (int i = 0; i < windows.size() - 1; ++i) {
        auto &window = windows[i];
        const auto initial_weight = window_weight(windows[i]);
        int idx_next_window = window.second;
        while (space[idx_next_window] <= space[idx_next_window - 1]) {
            inc_window(window, i);
        }
    }

    std::cout << windows_weight(windows) << '\n';
}

#endif

