#include <algorithm>
#include <iostream>
#include <cassert>
#include <vector>
#include <queue>
#include <cmath>

typedef long long llong;
const int MAXN = 80000 + 10;
const int MAXSIZE = 600;

int fenwick[MAXN], n, q;
void update(int pos, int value)
{
    for (int i = pos ; i <= n ; i += i & (-i))
    {
        fenwick[i] += value;
    }
}

int query(int pos)
{
    int result = 0;
    for (int i = pos ; i >= 1 ; i -= i & (-i))
    {
        result += fenwick[i];
    }

    return result;
}


std::vector < int > v[MAXN];
std::vector < int > byColor[MAXN];
llong precalc[MAXSIZE][MAXN];
llong sumOfChildren[MAXN];
llong currcnt[MAXN];
bool addded[MAXN];
int parent[MAXN];
int number[MAXN];
int bucketSize;
int out[MAXN];
llong c[MAXN];
int in[MAXN];
int bigCnt;

std::queue < int > waitList;
std::queue < std::pair < int, int > > waitList2;
std::vector < int > tour;

void buildTourDfs(int node, int p)
{
    parent[node] = p;
    in[node] = tour.size();
    tour.push_back(node);
    byColor[c[node]].push_back(node);

    for (int i : v[node])
    {
        if (i == p) continue;
        buildTourDfs(i, node);
    }

    out[node] = tour.size()-1;
    sumOfChildren[c[node]] += v[node].size() - (node != 1);
}

void dfsAdd(int node, int p, int currColor)
{
    if (node != 0) 
    {
        ++currcnt[c[node]];
        addded[c[node]] = 1;
    }

    for (int i : v[node])
    {
        if (i == p) continue;
        if (c[i] == currColor)
        {
            waitList.push(i);
            continue;
        }
        dfsAdd(i, node, currColor);
    }
}

void dfsRemove(int node, int p, int currColor)
{
    if (node != 0 && addded[c[node]])
    {
        // std::cout << "add: " << currColor << ' ' << c[node] << ' ' << currcnt[c[node]] << '\n';
        precalc[number[currColor]][c[node]] += currcnt[c[node]] * (currcnt[c[node]] - 1) / 2;
        addded[c[node]] = 0;
        currcnt[c[node]] = 0;
    }

    for (int i : v[node])
    {
        if (i == p) continue;
        if (c[i] == currColor) continue;
        dfsRemove(i, node, currColor);
    }
}

inline bool cmp(int x, int y)
{
    return in[x] <= in[y]-1;
}

inline int binSearch(int where, int value)
{
    int l = -1, r = byColor[value].size(), mid;
    while (l < r - 1)
    {
        mid = (l + r) / 2;
        if (in[byColor[value][mid]] <= where) l = mid;
        else r = mid;
    }

    return l+1;
}

inline int countOf(int l, int r, int value)
{
    return binSearch(r, value) - binSearch(l-1, value);
}

void solve()
{
    tour.reserve(n+1);
    tour.push_back(0);
    buildTourDfs(1, 0);
    v[0].push_back(1);

    // std::cout << "tour:\n";
    // for (int i : tour) std::cout << i << ' ';
    // std::cout << '\n';
    // std::cout << "color tour\n";
    // for (int i : tour) std::cout << c[i] << ' ';
    // std::cout << '\n';

    bucketSize = 0;
    for (int i = 1 ; i <= n ; ++i)
    {
        if (byColor[i].empty()) continue;
        if (sumOfChildren[i] >= bucketSize+1)
        {
            // std::cout << "big: " << i << '\n';
            number[i] = ++bigCnt;
            waitList.push(0);
            while (!waitList.empty())
            {
                int top = waitList.front();
                waitList.pop();
                for (int j : v[top])
                {
                    if (j == parent[top]) continue;
                    if (c[j] == i) waitList.push(j);
                    else
                    {
                        dfsAdd(j, top, i);
                        dfsRemove(j, top, i);
                    }
                }
            }
        }

        std::sort(byColor[i].begin(), byColor[i].end(), cmp);
        // std::cout << "by color sorted: " << i << '\n';
        // for (int j : byColor[i]) std::cout << j << ' ';
        // std::cout << '\n';
    }

    int x, y;
    for (int i = 1 ; i <= q ; ++i)
    {
        std::cin >> x >> y;
        if (byColor[x].size() <= 1)
        {
            std::cout << 0 << '\n';
            continue;
        }

        if (x == y || byColor[y].empty())
        {
            std::cout << byColor[x].size() * ((llong)(byColor[x].size()) - 1) / 2 << '\n';
            continue;
        }

        if (sumOfChildren[i] >= bucketSize+1)
        {
            std::cout << byColor[x].size() * ((llong)(byColor[x].size()) - 1) / 2 - precalc[number[y]][x] << '\n';
            continue;
        }

        int cnt = byColor[x].size(), ans = 0;
        for (int i = byColor[y].size()-1 ; i >= 0 ; --i)
        {
            int currNode;
            llong addValue;
            for (int currNode : v[byColor[y][i]])
            {
                if (currNode == parent[byColor[y][i]]) continue;
                addValue = countOf(in[currNode], out[currNode], x) - (query(out[currNode]) - query(in[currNode]-1));
                // std::cout << "component: " << currNode << ' ' << addValue << ' ' << query(out[currNode]) << ' ' << query(in[currNode]-1) << ' ' << in[currNode] << ' ' << out[currNode] << ' ' << countOf(in[currNode], out[currNode], x) << '\n';
                ans += addValue * (addValue - 1) / 2;
                cnt -= addValue;
                update(in[currNode], addValue);
                waitList2.push({in[currNode], addValue});
            }
            
        }

        while (!waitList2.empty())
        {
            auto [where, value] = waitList2.front();
            waitList2.pop();
            update(where, -value);
        }

        // std::cout << "component: " << cnt << '\n';
        llong sz = byColor[x].size();
        ans += cnt * (cnt-1) / 2;
        std::cout << sz * (sz-1) / 2 - ans << '\n';
    }
}

void read()
{
    std::cin >> n;
    for (int i = 1 ; i <= n ; ++i)
    {
        std::cin >> c[i];
    }

    int x, y;
    for (int i = 1 ; i <= n-1 ; ++i)
    {
        std::cin >> x >> y;
        v[x].push_back(y);
        v[y].push_back(x);
    }

    std::cin >> q;
}

void fastIO()
{
    std::ios_base :: sync_with_stdio(0);
    std::cout.tie(nullptr);
    std::cin.tie(nullptr);
}

int main()
{
    fastIO();
    read();
    solve();

    return 0;
}

/*
15
1 3 2 2 3 1 3 3 3 2 1 2 3 3 3
1 2
1 3
3 4
3 5
5 6
5 11
6 7
6 9
7 8
9 10
11 12
12 14
12 15
12 13
0

7
1 3 2 2 1 1 1
1 2
1 3
2 4
2 5
3 6
4 7
1
1 3

2 1
1 3
3 1
2 3
3 2

*/